@@ -176,12 +176,19 @@ def main(argv):
                 print('python -m artify -c create -f <template_file>')
                 print("Mandatory argument(s): ")
                 print('-f, --file    Template file to create e.g manifest, gitlabci')
+            elif arg == 'extract':
+                print('')
+                print('python -m artify -c extract \n')
+                print('Sample commit messages below: \n')
+                print("Added login functionality {\"version\": \"patch\", \"archtype\": \"npm\" } \n")
+                print("Added edit functionality {\"version\": \"minor\", \"a\": \"flutter\" } \n")
             else:
                 print('python -m artify --help nexus        Help on how to deploy to Nexus Repository')
                 print('python -m artify --help deploy       Help on how to deploy to AWX host')
                 print('python -m artify --help syncrepo     Help on how to commit and push code to repository')
                 print('python -m artify --help deltav       Help on how to change version number')
                 print("python -m artify --help create       Help on how to generate template files")
+                print("python -m artify --help extract      Help on how to use the extract command") 
                 return sys.exit(0)
         elif opt == "--debug":
             debug = 1
